<?php
/**
* @copyright	Copyright (C) 2009 - 2015 Ready Bytes Software Labs Pvt. Ltd. All rights reserved.
* @license		GNU/GPL, see LICENSE.php
* @package		plugin
* @subpackage	analytics
* @contact 		payplans@readybytes.in
*/

defined( '_JEXEC' ) or die( 'Restricted access' );

require_once(dirname(__FILE__) .DS.'analytics'.DS.'helper' .DS. 'helper.php');
class plgPayplansAnalytics extends XiPlugin
{		
	function __construct(& $subject, $config = array()){
		parent::__construct($subject, $config);
		
		$this->eventToTrack = $this->params->get('eventToTrack',array());
		$real_domain = JURI::getInstance()->getHost();
		$domain_filter = explode(',', $this->params->get('real_domain_filter',''));
		
		if(in_array($real_domain, $domain_filter) || empty($domain_filter)){
		   return true;
		}
		
		return false;
	}

	public function onAfterRoute()
        {
        	$app   = JFactory::getApplication();
        	$input = $app->input;
        
        	$pptracker	= $input->getCmd('ppemailtracker',null);
        
        	// TO use this image
        	// ppemailtracker=image&wv_email=john.doe@example.com&utm_variables
        	if($pptracker === 'image'){
        		
        		// track the event
        		$vars = array('utm_source'=>'','utm_medium'=>'','utm_campaign'=>'','utm_content'=>'','utm_term'=>'');
        		$args = $input->getArray($vars);
        			
        		$email = $input->getString('email');
        			
        		$event  = $input->get('event', '');
        		$event_name	= !empty($event) ? $event : 'email.open';
        
        		$args['email'] = $email;
        		$user = AnalyticsPluginHelper::_getUserId($email);
        		return AnalyticsPluginHelper::_trackEvent($user->id, $event_name, $args);

        		header("Content-type: image/png");
        		echo file_get_contents(__DIR__.'/analytics/beacon.png');
        		exit;
        	}
        }
	        
	//For tracking Events like "Plan Upgradation", "Subscription Status Change",etc.
	public function onPayplansSubscriptionAfterSave($prev, $new)
	{
		if($prev == null && $new->getStatus() == PayplansStatus::NONE){
			
			//Tracks Event Add To Cart Event
			$event_name	= 'COM_PAYPLANS_APP_ANALYTICS_SUBSCRIPTION_CREATION_EVENTNAME';
			
			if(in_array($event_name, $this->eventToTrack)){
				$event_name = JText::_($event_name);
				$args 	= AnalyticsPluginHelper::_getDetailSubscription($new);
				$email  = $new->getBuyer(true)->getEmail();
					
				$args['email'] = $email;
				$user = AnalyticsPluginHelper::_getUserId($email);
				return AnalyticsPluginHelper::_trackEvent($user->id, $event_name, $args,1);
			}
		}
		
		$status = $new->getStatus();
		$args 	= AnalyticsPluginHelper::_getDetailSubscription($new);
		$email  = $new->getBuyer(true)->getEmail();
			
		$args['email'] = $email;
		
		//For Tracking Upgradation of a plan.
		if($prev != null && $prev->getStatus() != PayplansStatus::SUBSCRIPTION_ACTIVE
				&& $new->getStatus() == PayplansStatus::SUBSCRIPTION_ACTIVE)
		{
			//Gets the order from subscription instance $new
			$order = $new->getOrder(PAYPLANS_INSTANCE_REQUIRE);
			$oldSubscriptionId = $order->getParam('upgrading_from',null);
			
			$user = AnalyticsPluginHelper::_getUserId($email);
			if(($order)	&& isset($oldSubscriptionId) && !empty($oldSubscriptionId))
			{
				//Tracks Event
				$event_name	= 'COM_PAYPLANS_APP_ANALYTICS_SUBSCRIPTION_UPGRADE_EVENTNAME';
				if(in_array($event_name, $this->eventToTrack)){
					$event_name = JText::_($event_name);
					return AnalyticsPluginHelper::_trackEvent($user->id, $event_name, $args);
				}
			}
		}
			
		switch ($status)
		{
			//Subscription active
			case PayplansStatus::SUBSCRIPTION_ACTIVE :
				$event_name	= 'COM_PAYPLANS_APP_ANALYTICS_SUBSCRIPTION_CREATION_EVENTNAME';
				break ;
	
				//Subscription expired
			case PayplansStatus::SUBSCRIPTION_EXPIRED:
				$event_name	= 'COM_PAYPLANS_APP_ANALYTICS_SUBSCRIPTION_EXPIRATION_EVENTNAME';
				break;
	
			// subscription hold
			case PayplansStatus::SUBSCRIPTION_HOLD:
				$event_name	= 'COM_PAYPLANS_APP_ANALYTICS_SUBSCRIPTION_HOLD_EVENTNAME';
				break;
	
			case PayplansStatus::NONE:
				return true;	
		}
		
		if(in_array($event_name, $this->eventToTrack)){
				$event_name = JText::_($event_name);
				return AnalyticsPluginHelper::_trackEvent($user->id, $event_name, $args);
		}
		return true;
	}
	
	//For Tracking "Check-out", "Paid", "refund"
	public function onPayplansInvoiceAfterSave($prev, $new)
	{
		if(!isset($prev) || !isset($new)){
			return true;
		}
		// Before save and after save, Invoice status should not be same.
		if ($new->getStatus() == $prev->getStatus()){
			return true;
		}
	
		//Initialize Tracking of KM
		$status = $new->getStatus();
		
		$args 	= AnalyticsPluginHelper::_getDetailInvoice($new);
		$email  = $new->getBuyer(true)->getEmail();
		
		$args['email'] = $email;
		$user = AnalyticsPluginHelper::_getUserId($email);
		
		//Which Event to track, Decision made on status of invoice from $new
		switch ($status)
		{
			// Invoice paid
			case PayplansStatus::INVOICE_PAID :
				$event_name	= 'COM_PAYPLANS_APP_ANALYTICS_INVOICE_PAID_EVENTNAME';
				break ;
	
				// Invoice Refund
			case PayplansStatus::INVOICE_REFUNDED:
				$event_name	= 'COM_PAYPLANS_APP_ANALYTICS_INVOICE_REFUND_EVENTNAME';
				break;
	
			// Invoice Confirm or none
			case PayplansStatus::INVOICE_CONFIRMED:
				$event_name	= 'COM_PAYPLANS_APP_ANALYTICS_INVOICE_CHECKOUT_EVENTNAME';
				
				break;
	
			case PayplansStatus::NONE:
				return true;
		}
		
		if(in_array($event_name, $this->eventToTrack)){
					$event_name = JText::_($event_name);
					return AnalyticsPluginHelper::_trackEvent($user->id, $event_name, $args);
		}
	}
	
	
	public function onPayplansSubscriptionRenewalComplete($subscription, $new)
		{
		
			$event_name	= 'COM_PAYPLANS_APP_ANALYTICS_SUBSCRIPTION_RENEWAL_EVENTNAME';
			if(in_array($event_name, $this->eventToTrack)){
				$args 	= AnalyticsPluginHelper::_getDetailInvoice($new);
				$email  = $new->getBuyer(true)->getEmail();
				
				$args['email'] = $email;
				$user = AnalyticsPluginHelper::_getUserId($email);
				$event_name = JText::_($event_name);
				return AnalyticsPluginHelper::_trackEvent($user->id, $event_name, $args);
			}
		}
		
	
	public function onPayplansDiscountAfterApply($invoice, $discountCode){
		
		$event_name	= 'COM_PAYPLANS_APP_ANALYTICS_DISCOUNT_CONSUMED_EVENTNAME';
		
		if(in_array($event_name, $this->eventToTrack)){
				$args 	= AnalyticsPluginHelper::_getDetailInvoice($invoice);
				$email  = $invoice->getBuyer(true)->getEmail();
				
				$args['discount_code_utilized'] = $discountCode;
				
				$args['email'] = $email;
				$user = AnalyticsPluginHelper::_getUserId($email);
				$event_name = JText::_($event_name);
				return AnalyticsPluginHelper::_trackEvent($user->id, $event_name, $args);
		}
	
	}
	
	public function onPayplansPaymentAfterSave($prev, $new)
		{
			if($prev == null){
				$event_name    = 'COM_PAYPLANS_APP_ANALYTICS_PAYMENT_GATEWAY_USED_EVENTNAME';
				if(in_array($event_name, $this->eventToTrack)){
					$args['paymentGateway'] = $new->getAppName();
					$email 			= $new->getBuyer(true)->getEmail();
					$args['email'] = $email;
					$user = AnalyticsPluginHelper::_getUserId($email);
					$event_name = JText::_($event_name);
					return AnalyticsPluginHelper::_trackEvent($user->id, $event_name, $args);
				}
			}
		}
	
	public function onPayplansGetPlugin()
		{
		    $xml = dirname(__FILE__).DS.'analytics.xml';
		    if (file_exists($xml)) {
		           $xmlContent = simplexml_load_file($xml);
		     }
		     else {
		           $xmlContent = null;
		     }
		     return array('name'   => 'analytics', 
		             	  'value' =>$xmlContent);
		 }
 
}